#
# spec file for package gdal
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ecw_support
# Soname should be bumped on API/ABI break
# http://trac.osgeo.org/gdal/ticket/4543
%define soversion 20
%define sourcename gdal

Name:           gdal
Version:        2.1.0
Release:        1.28
Summary:        GDAL/OGR - a translator library for raster and vector geospatial data formats
License:        MIT and BSD-3-Clause and SUSE-Public-Domain
Group:          Development/Libraries/C and C++
Url:            http://www.gdal.org/
Source0:        http://download.osgeo.org/%{name}/%{version}/%{sourcename}-%{version}.tar.xz
Patch0:         gdal-perl.patch
# Fix occasional parallel build failure
Patch1:         GDALmake.opt.in.patch
# Fix hard coded name of libproj library
# But libproj.so is valid if libproj-devel is installed ?
Patch2:         gdal-libproj.patch
Patch3:         ogr_wrap.patch
BuildRequires:  blas-devel
BuildRequires:  chrpath
BuildRequires:  curl-devel
BuildRequires:  dos2unix
BuildRequires:  doxygen >= 1.4.2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  geos-devel >= 3
BuildRequires:  giflib-devel
BuildRequires:  lapack-devel
BuildRequires:  libexpat-devel >= 1.95.0
BuildRequires:  libgeotiff-devel >= 1.2.1
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libproj-devel
BuildRequires:  libspatialite-devel
BuildRequires:  libtiff-devel >= 3.6.0
BuildRequires:  libtool
BuildRequires:  libxerces-c-devel
BuildRequires:  libxml2-devel
BuildRequires:  mysql-devel
BuildRequires:  netcdf-devel
BuildRequires:  opencl-headers
BuildRequires:  openjpeg2-devel
BuildRequires:  perl-macros
BuildRequires:  php5-devel
BuildRequires:  poppler-devel
BuildRequires:  postgresql-devel
BuildRequires:  python-numpy-devel
BuildRequires:  python-setuptools
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-setuptools
BuildRequires:  sqlite-devel >= 3
BuildRequires:  swig
BuildRequires:  unixODBC-devel
BuildRequires:  xz-devel
BuildRequires:  zlib-devel >= 1.1.4
%if %{with ecw_support}
BuildRequires:  libecwj2-devel
%endif
%if 0%{?suse_version} >= 1310
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  freexl-devel
BuildRequires:  hdf5-devel
BuildRequires:  libwebp-devel
%endif
%if 0%{?suse_version} > 1320
BuildRequires:  libjson-c-devel
BuildRequires:  ocl-icd-devel
BuildRequires:  opencl-headers
BuildRequires:  perl-ExtUtils-MakeMaker
%else
BuildRequires:  hdf-devel >= 4.0
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GDAL is a translator library for raster geospatial data formats that
is released under an Open Source license. As a library, it presents a
single abstract data model to the calling application for all
supported formats. The related OGR library (which lives within the
GDAL source tree) provides a similar capability for simple features
vector data.

%package devel
Summary:        GDAL library header files
Group:          Development/Languages/C and C++
Requires:       lib%{name}%{soversion} = %{version}
Provides:       lib%{name}%{soversion}-devel
Provides:       lib%{name}-devel

%description devel
Development Libraries for the GDAL file format library

%package -n lib%{name}%{soversion}
Summary:        GDAL static libraries
Group:          System/Libraries

%description -n lib%{name}%{soversion}
GDAL and OGR are translator libraries for raster and vector geospatial data
formats. As a library, it presents a single abstract data model to the calling
application for all supported formats.

%package -n perl-%{name}
Summary:        Perl bindings for GDAL
Group:          Development/Languages/Perl
Requires:       %{name} = %{version}-%{release}
%if 0%{?suse_version} < 1140
Requires:       perl = %{perl_version}
%else
%{perl_requires}
%endif

%description -n perl-%{name}
Perl bindings for GDAL - Geo::GDAL, Geo::OGR and Geo::OSR modules.

%package -n python-%{name}
Summary:        GDAL Python module
Group:          Development/Languages/Python
Requires:       %{name} = %{version}-%{release}
%py_requires

%description -n python-%{name}
The GDAL python modules provide support to handle multiple GIS file formats.

%package -n python3-%{name}
Summary:        GDAL Python3 module
Group:          Development/Languages/Python
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{name}
The GDAL python modules provide support to handle multiple GIS file formats.

%prep
%setup -q -n %{sourcename}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# Fix mandir
sed -i "s|^mandir=.*|mandir='\${prefix}/share/man'|" configure

# Fix wrong encoding EOL
for F in frmt_twms_srtm.xml frmt_wms_bluemarble_s3_tms.xml frmt_wms_virtualearth.xml frmt_twms_Clementine.xml;do
  find . -name "${F}" -exec dos2unix {} \;
done

%build
# need to regenerate (old one does not accpet CFLAGS)
%if 0%{?suse_version} >= 1310
mv configure.in configure.ac
autoreconf -fi
%endif

%configure \
        --prefix=%{_prefix}     \
        --includedir=%{_includedir}/gdal \
        --datadir=%{_datadir}/gdal \
        --with-threads          \
        --disable-static        \
        --with-geotiff          \
        --with-libtiff          \
        --with-rename-internal-libtiff-symbols=yes \
        --with-rename-internal-libgeotiff-symbols=yes \
        --with-libz             \
        --with-cfitsio=no       \
        --with-netcdf           \
        --with-openjpeg         \
        --with-curl             \
        --with-pg               \
        --with-ogdi             \
        --without-pcraster      \
        --with-jpeg12=no        \
        --without-libgrass      \
        --without-grass         \
        --enable-shared         \
        --with-geos             \
        --with-expat            \
        --with-jasper           \
        --with-png              \
        --with-gif              \
        --with-jpeg             \
        --with-spatialite       \
        --with-poppler          \
        --with-python           \
        --with-perl             \
        --with-mysql            \
        --with-freexl           \
        --with-xerces=yes       \
        --with-xerces-lib="-lxerces-c" \
        --with-xerces-inc=%{_includedir}/xercesc \
%if %{with ecw_support}
        --with-ecw              \
        CFLAGS="$CFLAGS -pthread" \
%endif
%if 0%{?suse_version} > 1320
        --with-opencl           \
%endif
%if 0%{?suse_version} > 1310
        --without-hdf4          \
        --with-hdf5             \
        --with-webp             \
%else
        --with-hdf4             \
%endif
        --disable-rpath

# regenerate where needed
for M in perl python;
do
  make %{?_smp_mflags} -C swig/${M} veryclean
  make %{?_smp_mflags} -C swig/${M} generate
done

make %{?_smp_mflags} VERBOSE=1 all docs man

# Make Python 3 module
pushd swig/python
  python3 setup.py build
popd

%install

# Install Python 3 module
# Must be done first so executables are env python
pushd swig/python
  python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
popd

make %{?_smp_mflags} install install-man \
  DESTDIR=%{buildroot} INST_MAN=%{_mandir}

# Not on buildroot : broke everything with python3
# If done got python3 needing python2 package heretic ..
# Futhermore duplicates are only existing in src html dir
%fdupes -s html
# Empty file
rm -f html/do-not-remove

# chrpath must be removed here
chmod 644 %{buildroot}%{perl_vendorarch}/auto/Geo/GDAL/Const/Const.so
chmod 644 %{buildroot}%{perl_vendorarch}/auto/Geo/GDAL/GDAL.so
chmod 644 %{buildroot}%{perl_vendorarch}/auto/Geo/OGR/OGR.so
chmod 644 %{buildroot}%{perl_vendorarch}/auto/Geo/OSR/OSR.so

chrpath --delete %{buildroot}%{perl_vendorarch}/auto/Geo/GDAL/Const/Const.so
chrpath --delete %{buildroot}%{perl_vendorarch}/auto/Geo/GDAL/GDAL.so
chrpath --delete %{buildroot}%{perl_vendorarch}/auto/Geo/OGR/OGR.so
chrpath --delete %{buildroot}%{perl_vendorarch}/auto/Geo/OSR/OSR.so

%if 0%{?suse_version} <= 1315
# perl bs 0 length files cleanup
find %{buildroot}%{perl_vendorarch} -iname "*.bs" -exec rm -fv {} \;
# Those are deleted.
#%%{perl_vendorarch}/auto/Geo/OSR/OSR.bs
#%%{perl_vendorarch}/auto/Geo/OGR/OGR.bs
#%%{perl_vendorarch}/auto/Geo/GDAL/GDAL.bs
#%%{perl_vendorarch}/auto/Geo/GDAL/Const/Const.bs
%endif

# do not ship these
rm -rf %{buildroot}%{_mandir}/man1/_*
rm -rf %{buildroot}%{_libdir}/libgdal.la
rm -rf %{buildroot}%{perl_archlib}/perllocal.pod
rm -rf %{buildroot}%{perl_vendorarch}/auto/Geo/*/.packlist
rm -rf %{buildroot}%{perl_vendorarch}/auto/Geo/GDAL/Const/.packlist
rm -rf %{buildroot}%{_bindir}/*.dox

# avoid PACKAGE redefines
sed -i 's,\(#define PACKAGE_.*\),/* \1 */,' %{buildroot}%{_includedir}/gdal/cpl_config.h

%post -n lib%{name}%{soversion} -p /sbin/ldconfig

%postun	-n lib%{name}%{soversion} -p /sbin/ldconfig

%files -n lib%{name}%{soversion}
%defattr(644,root,root,755)
%{_libdir}/*.so.%{soversion}.*
%{_libdir}/*.so.%{soversion}

%files
%defattr(644,root,root,755)
%doc NEWS PROVENANCE.TXT
%defattr(755,root,root,755)
%{_bindir}/epsg_tr.py
%{_bindir}/esri2wkt.py
%{_bindir}/gcps2vec.py
%{_bindir}/gcps2wld.py
%{_bindir}/gdal2tiles.py
%{_bindir}/gdal2xyz.py
%{_bindir}/gdal_auth.py
%{_bindir}/gdal_calc.py
%{_bindir}/gdal_contour
%{_bindir}/gdal_edit.py
%{_bindir}/gdal_fillnodata.py
%{_bindir}/gdal_grid
%{_bindir}/gdal_merge.py
%{_bindir}/gdal_polygonize.py
%{_bindir}/gdal_proximity.py
%{_bindir}/gdal_pansharpen.py
%{_bindir}/gdal_rasterize
%{_bindir}/gdal_retile.py
%{_bindir}/gdal_sieve.py
%{_bindir}/gdal_translate
%{_bindir}/gdaladdo
%{_bindir}/gdalbuildvrt
%{_bindir}/gdalchksum.py
%{_bindir}/gdalcompare.py
%{_bindir}/gdaldem
%{_bindir}/gdalenhance
%{_bindir}/gdalident.py
%{_bindir}/gdalimport.py
%{_bindir}/gdalinfo
%{_bindir}/gdallocationinfo
%{_bindir}/gdalmanage
%{_bindir}/gdalmove.py
%{_bindir}/gdalserver
%{_bindir}/gdalsrsinfo
%{_bindir}/gdaltindex
%{_bindir}/gdaltransform
%{_bindir}/gdalwarp
%{_bindir}/mkgraticule.py
%{_bindir}/nearblack
%{_bindir}/ogr2ogr
%{_bindir}/ogrinfo
%{_bindir}/ogrlineref
%{_bindir}/ogrtindex
%{_bindir}/pct2rgb.py
%{_bindir}/rgb2pct.py
%{_bindir}/testepsg
%defattr(644,root,root,755)
%{_datadir}/gdal
%{_mandir}/man1/gdal2tiles.1*
%{_mandir}/man1/gdal_calc.1*
%{_mandir}/man1/gdal_contour.1*
%{_mandir}/man1/gdal_edit.1*
%{_mandir}/man1/gdal_fillnodata.1*
%{_mandir}/man1/gdal_grid.1*
%{_mandir}/man1/gdal_merge.1*
%{_mandir}/man1/gdal_pansharpen.1*
%{_mandir}/man1/gdal_polygonize.1*
%{_mandir}/man1/gdal_proximity.1*
%{_mandir}/man1/gdal_rasterize.1*
%{_mandir}/man1/gdal_retile.1*
%{_mandir}/man1/gdal_sieve.1*
%{_mandir}/man1/gdal_translate.1*
%{_mandir}/man1/gdal_utilities.1*
%{_mandir}/man1/gdaladdo.1*
%{_mandir}/man1/gdalbuildvrt.1*
%{_mandir}/man1/gdalcompare.1*
%{_mandir}/man1/gdaldem.1*
%{_mandir}/man1/gdalinfo.1*
%{_mandir}/man1/gdallocationinfo.1*
%{_mandir}/man1/gdalmanage.1*
%{_mandir}/man1/gdalmove.1*
%{_mandir}/man1/gdalsrsinfo.1*
%{_mandir}/man1/gdaltindex.1*
%{_mandir}/man1/gdaltransform.1*
%{_mandir}/man1/gdalwarp.1*
%{_mandir}/man1/gnm_utilities.1*
%{_mandir}/man1/gnmanalyse.1*
%{_mandir}/man1/gnmmanage.1*
%{_mandir}/man1/nearblack.1*
%{_mandir}/man1/ogr2ogr.1*
%{_mandir}/man1/ogr_utilities.1*
%{_mandir}/man1/ogrinfo.1*
%{_mandir}/man1/ogrlineref.1*
%{_mandir}/man1/ogrtindex.1*
%{_mandir}/man1/pct2rgb.1*
%{_mandir}/man1/rgb2pct.1*

%files devel
%defattr(-,root,root)
%doc NEWS PROVENANCE.TXT LICENSE.TXT
%defattr(644,root,root,755)
%doc html
%attr(755,root,root) %{_bindir}/gdal-config
%{_libdir}/libgdal.so
%{_libdir}/pkgconfig/gdal.pc
%dir %{_includedir}/gdal
%{_includedir}/gdal/*.h
%{_mandir}/man1/gdal-config.1*

%files -n perl-%{name}
%defattr(-,root,root)
%doc NEWS PROVENANCE.TXT LICENSE.TXT
%{perl_vendorarch}/Geo/GDAL.pm
%dir %{perl_vendorarch}/Geo/GDAL
%{perl_vendorarch}/Geo/GDAL/Const.pm
%{perl_vendorarch}/Geo/OGR.pm
%{perl_vendorarch}/Geo/OSR.pm
%dir %{perl_vendorarch}/Geo
%dir %{perl_vendorarch}/auto/Geo
%dir %{perl_vendorarch}/auto/Geo/GDAL
%attr(755,root,root) %{perl_vendorarch}/auto/Geo/GDAL/GDAL.so
%dir %{perl_vendorarch}/auto/Geo/GDAL/Const
%attr(755,root,root) %{perl_vendorarch}/auto/Geo/GDAL/Const/Const.so
%dir %{perl_vendorarch}/auto/Geo/OGR
%attr(755,root,root) %{perl_vendorarch}/auto/Geo/OGR/OGR.so
%dir %{perl_vendorarch}/auto/Geo/OSR
%attr(755,root,root) %{perl_vendorarch}/auto/Geo/OSR/OSR.so
%{_mandir}/man3/Geo::GDAL.3*

%files -n python-%{name}
%defattr(644,root,root,755)
%doc NEWS PROVENANCE.TXT LICENSE.TXT
%{python_sitearch}/*

%files -n python3-%{name}
%defattr(644,root,root,755)
%doc NEWS PROVENANCE.TXT LICENSE.TXT
%{python3_sitearch}/*

%changelog
* Tue May 10 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- New upstream release 2.1.0
  - https://trac.osgeo.org/gdal/wiki/Release/2.1.0-News
- packaging changes
  - Removed gdal-python_install.patch
  - Removed gdal-2.0.2-sqlite-crash.patch
  - Removed gdal-configure.patch
  - Added ogr_wrap.patch to solve no-return-in-non-void-function error
  - Submitted ogr_wrap.patch upstream: https://trac.osgeo.org/gdal/ticket/6506
  - Redone patch GDALmake.opt.in.patch
* Tue Feb 23 2016 bruno@ioda-net.ch
- Upgrade to 2x series version : 2.0.2 bugfix release
  - https://trac.osgeo.org/gdal/wiki/Release/2.0.2-News
  - https://trac.osgeo.org/gdal/wiki/Release/2.0.1-News
  - https://trac.osgeo.org/gdal/wiki/Release/2.0.0-News
- packaging
  - Redone patch GDALmake.opt.in.patch and gdal-libproj.patch
  - Delete upstream merged gdal-python-swig3-issue6045.path
  - Delete upstream merged gdal_swig-perl-issue3084.patch
  - Add gdal-2.0.2-sqlite-crash.patch Fix upstream issue 6360
  - spec-cleaner minimal (pkgconfig make unresolvable all except
    Leap and Tumbleweed)
* Thu Feb  4 2016 behrisch@users.sourceforge.net
- Fixing PACKAGE_* redefines in cpl_config.h
* Sun Jan 31 2016 Angelos Tzotsos <tzotsos@opensuse.org>
- New upstream patch release 1.11.4
* Wed Dec  9 2015 mpluskal@suse.com
- Enable opencl and freexl support
- Update dependencies
* Fri Sep 25 2015 ecsos@opensuse.org
- Upgrade to version 1.11.3
  see http://trac.osgeo.org/gdal/wiki/Release/1.11.3-News
- remove following patches, because their are now in source:
  - gdal-poppler-0.31.patch
  - gdal-python-swig3-issue6045.patch
  - gdal-gcc5-getaddrinfo-issue6073.patch
* Fri Aug 28 2015 bruno@ioda-net.ch
- packaging
  Redone exclusion for <= 1310 and 1315
  Cleanup empty perl bs files
- Build fixes
  * Fix python coding in swig3+ (backport of gdal20)
  with patch gdal-python-swig3-issue6045.patch
  * Fix gcc5 build upstream issue 6073
  gdal-gcc5-getaddrinfo-issue6073.patch
* Wed Aug 26 2015 bruno@ioda-net.ch
- Adding python3 support
- move fdupes from buildroot (mix python scripts otherwise)
  fdupes is run against source html directory
- dos2unix Fix EOL warnings
* Sat Jul  4 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- Fix build to use libproj9
* Fri May 29 2015 guillaume@opensuse.org
- Fix ECW detection in configure script (need to add -pthread to CFLAGS)
* Sat May  2 2015 ecsos@opensuse.org
- Upgrade to version 1.11.2
  * Build
  - configure: fix detection of OCI by changing linking order
    to please modern GCC (#5550)
  - configure: fix test to accept MariaDB 10.X as valid MySQL
    (#5722)
  - More compiler warnings addressed (#5414)
  - Windows build of PDF: fix compilation issue with
    Visual Studio 2012 (#5744)
  - Windows build: Add support for MrSID 9.1 SDK (#5814)
  - Windows build: when building netCDF, HDF4, HDF5 as plugins,
    call registration of 'sub-drivers' GMT, HDF4Image and
    HDF5Image (#5802)
  * Port
  - CSV finder: Stop probing for csv/horiz_cs.csv. (#5698)
  - /vsicurl/: avoid reading after end-of-file and fix failure
    when reading more than 16MB in a single time (#5786)
  - CPLHexToBinary(): faster implementation (#5812)
  * GDAL Core and algorithms
  - Make GetMaskBand?() work with GDT_UInt16 alpha bands (#5692)
  - Fix 32bit overflow in GDALRasterBand::IRasterIO() (#5713)
  - RPC transformer: take into account nodata in RPC DEM (#5680)
  - RPC transformer: add RPC_DEM_MISSING_VALUE transformer option
    to avoid failure when there's no DEM at the transformed point
    (#5730)
  - Fix GDALSuggestedWarpOutput() wrong extent in some
    circumstances (e.g. dataset of big dimension with world
    coordinates) (#5693)
  - Fix crash when calling GetTiledVirtualMem?() on non-Linux
    platform (#5728)
  - warp: fix integer overflow when reprojecting into an area
    with (part of) bounds completely outside of the source
    projection (#5789)
  - OpenCL warper: fix OpenCL code compilation with NVIDIA OpenCL
    (#5772)
  * Utilities
  - gdalwarp: initialize destination dataset to no_data value
    when automatically propagating source nodata (#5675)
  - gdalwarp: only apply INIT_DEST when processing the first
    input dataset (#5387)
  - gdaldem: avoid too large files to be produced when using
  - co COMPRESS=xxxx -co TILED=YES (#5678)
  * GDAL drivers
  - GRASS driver:
  - fix compilation issues against GRASS 7 (#2953)
  - GIF driver:
  - fix crash on images without color table (#5792)
  - validate the size of the graphic control extension block
  (#5793)
  - GTiff driver:
  - Internal overviews: for near, average, gauss, and pixel
  interleaving, make sure to use the same code path for
  compressed vs uncompressed overviews (#5701)
  - allow lossless copying of CMYK JPEG into JPEG-in-TIFF
  (#5712)
  - when overriding metadata in update mode, make sure to clear
  it from PAM file (#5807)
  - fix GTiffRasterBand::DirectIO() to work with TIFF files
  with multiple directories (overviews, masks) (#5831)
  - Internal libtiff: partial (mostly security related fixes)
  upgrade to 4.0.4beta (#5830)
  - ISIS3 driver:
  - fix to recognize IsisCube?.Mapping.LatitudeType? =
  Planetocentric (#5717)
  - JP2OpenJPEG driver:
  - add compatibility with OpenJPEG 2.1 (#5579)
  - JPEG driver:
  - Report non-fatal libjpeg errors as CE_Warning
  (or CE_Failure if GDAL_ERROR_ON_LIBJPEG_WARNING = TRUE)
  (#5667)
  - KMLSuperOverlay driver:
  - remove useless and unreliable computations on floating
  point numbers that caused issues (truncated raster)
  on 32bit (#5683)
  - USGSDEM driver:
  - take into account horizontal unit = ft in the UTM case
  (#5819)
  - VRT driver:
  - fix RasterIO() to be able to fill buffers larger than 2GB
  (#5700, #5734)
  * OGR core
  - ogr_core.h: only ignore -Wfloat-equal for IsInit?() and not
    for the rest of the file and files that inc it (#5299)
  - OGR layer algebra: properly initialize field maps to avoid
    Valgrind warnings in OGRLayer::Update() (#5778)
  * OGR drivers
  - CSV driver:
  - fix segfault when reading allCountries.txt of geonames.org
  (#5668)
  - FileGDB:
  - avoid emitting error when opening a FileGDB v9, so that
  OpenFileGDB can be tried to open it, in the case FileGDB
  is a plugin (#5674)
  - GeoJSON driver:
  - ESRIJson: parse correctly rings of esriGeometryPolygon
  objects to build correct Polygon or MultiPolygon? (#5538)
  - GML driver:
  - Fix incorrect geometry cast when reading GML topogeometries
  (#5715)
  - Update GFS files for RUIAN (UVOH & OB) (#5770)
  - LIBKML driver:
  - when skipped, fix segfault on second OGRRegisterAll() call
  (#5775)
  - do not delete the libkml singleton factory (linked to #5775)
  - MapInfo? File driver:
  - Add GDA94 datum entries to the lookup table (#5671)
  - fix segfault in CreateFeature?() if passing an invalid OGR
  feature style string (#1209)
  - MSSQL driver:
  - Fix recognizing image columns as geometry columns for the
  select layers. (#5498)
  - Fix issue when creating non-spatial table (#5696)
  - Fix to read metadata if the tables are specified in the
  connection string (#5796)
  - Fix invalid use of CSLAddString() in OGR MSSQL (#5810)
  - Fix crash if the tablename is specified in the connection
  string (#5826)
  - MySQL driver:
  - don't be dependant on locale when building spatial filter
  (#5720)
  - NAS driver:
  - make chevrons configurable by NAS_INDICATOR (#5708)
  - OCI driver:
  - Initialize member variable to avoid UpdateLayerExtents?()
  to be called randomly on non spatial tables (#5376)
  - fix FID (multi_load=off, OGRNullFID) - start with 1
  (not -1) (#5454)
  - OpenFileGDB driver:
  - fix ResetReading?() on SQL layer with ORDER BY on indexed
  column (#5669)
  - add support for non spatial GDB v9 tables (#5673)
  - PG driver:
  - fix GDAL 1.11.0 regression that prevented to retrieve more
  than 500 features from a connection with tables= parameter
  and on a SQL result layer (#5837)
  - SQLite/Spatialite driver:
  - remove 'T' suffix when formatting the content of a Date
  field (#5672)
  - fix segmentation fault when executing OGR2SQLITE_Register()
  when compiling against sqlite 3.8.7 (#5725)
  - make GetFIDColumn() work when run as first method call
    (#5781)
  - VRT driver:
  - do not propagate ignoring of x and y cols of a
  PointFromColumns? to the source layer (#5777)
  - XLSX driver:
  - fix column numbering when there are more than 26 columns
  (#5774)
  * SWIG Language Bindings
  - Python bindings:
  - Fix hang of Python in case of repeated call to gdal/ogr.
  UseExceptions?() and CE_Warning emitted (#5704)
  - fix processing error of ogr_python.i with SWIG 3 (#5795)
  - NUMPY driver: avoid returning CE_None in GetGeoTransform?()
  when there's no geotransform set (#5801)
* Fri Mar 27 2015 dimstar@opensuse.org
- Add gdal-poppler-0.31.patch: Fix build with poppler 0.31+.
* Tue Mar 10 2015 schubert.seb@gmail.com
- Fix hard coded proj4 library name
  * gdal-libproj.patch
* Sun Mar  8 2015 mpluskal@suse.com
- Update perl package dependencies
* Mon Feb  9 2015 mpluskal@suse.com
- Add GDALmake.opt.in.patch to fix random failures of parallel
  builds
* Mon Feb  9 2015 mpluskal@suse.com
- Build with hdf5 on suse recent suse releases.
- Correct license and bundle license with packages.
- Misc spec file cleanups.
- Build with webp support if possible.
- Use autoreconf when possible to avoid issues with improper
  cflags used and parallel builds.
- Rename package to match upstream name (gdal) - library is
  provided as libgdal1 which matches shared libraries policy.
* Tue Dec 16 2014 guillaume@opensuse.org
- Add optional support to ECW JPEG lib support (disabled by default)
* Sat Oct 11 2014 behrisch@users.sourceforge.net
- fixing build with older autotools (SLE11SP3, CentOS6)
- removing obsolete patch
* Thu Oct  2 2014 ecsos@schirra.net
  Upgrade to version 1.11.1
- Build
  * Fix compilation errors with json-c 0.12 (#5449)
  * configure: fix for cpl_recode_iconv.cpp compilation error
    on freebsd 10 (#5452)
  * Fix compilation error in alg/gdalgrid.cpp when AVX is available,
    but not SSE (#5566)
  * Fix wrong include order in ingr and nitf subdirs w.r.t internal
    libtiff (#5644)
  * Add CPL_UNUSED for gcc >= 4 (#5414)
- Port
  * CPLSpawn() on Windows: quote arguments with spaces
    in them (#5469)
  * /vsigzip/: avoid infinite loop when reading broken
    .gml.gz file (#5486)
  * /vsizip/: fix bug that caused premature end of file condition
    with some read patterns (#5530)
  * /vsizip/: on >4GB zips: accept .zip declare 0 disks (#5615)
  * Fix stack corruption upon thread termination with
    CPLSetThreadLocalConfigOption on Windows 32 bit (#5590,
    reported by cleo)
  * cpl_http.cpp: truly set CURLOPT_NOSIGNAL if available (#5568)
- GDAL Core
  * EXIF reader: add missing validation for some data types (#3078)
  * Fix segfault in GDALPamRasterBand::SerializeToXML() when
    saving an empty RAT (#5451)
  * Windows plugin: complementary fix to #5211 to avoid error
    dialog box when there are dependency problems (#5525)
  * RPC transformer with DEM: fix near interpolation
    (patch by liminlu0314, #5553)
  * OpenCL warper: remove unused variable in bilinear resampling
    that can cause compilation error (#5518)
  * GDALCreateTPSTransformer(): fix crash if the forward or backward
    transform cannot be computed (#5588)
  * Overview: ignore alpha=0 values when compute an average overview
    of an alpha band; and also avoid memory errors when calling
    GetMaskBand?()/GetMaskFlags() after overview computation if
    GetMaskXXX() has been called before (#5640)
- Utilities
  * gdal2tiles.py: fix inverted long/lat in BoundingBox? and
    Origin elements of tilemapresource.xml (#5336)
  * pct2rgb.py: make it work (again) with color tables with
    less than 256 entries (#5555)
  Previous upgrades from version 1.11.0
- New GDAL drivers:
  * KRO: read/write support for KRO KOKOR Raw format
- New OGR drivers:
  * CartoDB : read/write support
  * GME (Google Map Engine) : read/write support
  * GPKG (GeoPackage): read-write support (vector part of the spec.)
  * OpenFileGDB: read-only support (no external dependency)
  * SXF: read-only support
  * WALK : read-only support
  * WAsP .map : read-write support
- Significantly improved drivers: GML, LIBKML
- RFC 40: enhanced RAT support (#5129)
- RFC 41: multiple geometry fields support
- RFC 42: OGR Layer laundered field lookup
- RFC 43: add GDALMajorObject::GetMetadataDomainList?() (#5275)
- RFC 45: GDAL datasets and raster bands as virtual memory mapping
- Upgrade to EPSG 8.2 database
* Thu Oct  3 2013 Angelos Tzotsos <tzotsos@opensuse.org>
  Upgrade to version 1.10.1:
- Compilation fixes for iOS (#5197, #5198)
- Fix VSISubFileHandle::Eof() behaviour to be POSIX compliant, so that the shapefile reader can read the last feature when using /vsitar (#5093)
- vsicache: fix for 32bit binaries when file size is over 2GB (#5170)
- warper: Fix warping when input pixel size is too close to 0 (#5190)
- GDALFillNodata(): Fix use of uninitialized memory and integer overflows (#4010, #5203)
- Fix ref-counting of callable passed to gdal.PushErrorHandler?() (#5186)
* Mon Jun  3 2013 dvaleev@suse.com
- install man to the %%{_mandir}
* Sat May 25 2013 behrisch@users.sourceforge.net
- removing dox from RHEL and derivatives
* Thu May 23 2013 behrisch@users.sourceforge.net
- added dependency to libltdl for the devel package
* Wed May  8 2013 behrisch@users.sourceforge.net
- Added openjpeg2 to the devel requirements
* Mon Apr 29 2013 Angelos Tzotsos <tzotsos@opensuse.org>
  Upgrade to version 1.10 final:
  * New GDAL drivers:
  - ARG: read/write suuport for ARG datasets (#4591)
  - CTable2: read/write support for CTable2 datum grid shift format
  - DDS: write-only support for DirectDraw? Surface format (#5017)
  - IRIS: read support for products generated by the IRIS weather radar software (#4854)
  - MAP: read OziExplorer? .map files (#3380)
  - MBTiles: read-only support for MBTiles rasters (needs libsqlite3)
  * New OGR drivers:
  - ElasticSearch?: write-only support to write into ElasticSearch? databases (needs libcurl)
  - ODS : read/write support for OpenOffice? .ods (Open Document Spreadsheets) (needs libexpat)
  - OSM : read-only support for .osm / .pbf OpenStreetMap? files
  - PDF: read/write support for vector/structured PDF files
  - XLSX: read/write support for MS Excel 2007 and later Open Office XML .xlsx spreadsheets (needs libexpat)
  * RFC 39: OGR Layer algebra methods : http://trac.osgeo.org/gdal/wiki/rfc39_ogr_layer_algebra
  * Add a SQL SQLite dialect :  http://gdal.org/ogr/ogr_sql_sqlite.html
  * Make GDAL loadable as a SQLite3 extension (named VirtualOGR) (#4782)
  * /vsicurl_streaming/: new virtual file system handler designed to read in streaming mode dynamically generated files
  * GDAL API_PROXY mechanism to run GDAL drivers in a separate process:  http://gdal.org/gdal_api_proxy.html
  * Significantly improved drivers : PDF, SQLite, JP2OpenJPEG
  * Add a geocoding client :  http://gdal.org/ogr/ogr__geocoding_8h.html
  * Upgrade to EPSG 8.0 database
* Thu Apr 18 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- Upgraded to version 1.10RC3
* Sun Apr 14 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- Upgraded to version 1.10RC2
* Sun Apr 14 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- Upgraded to version 1.10RC1
* Mon Apr  8 2013 Angelos Tzotsos <tzotsos@opensuse.org>
- Restored OpenJPEG2000 dependency
- Upgraded to version 1.10beta2
* Tue Dec  4 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Removed hardcoded Requires
* Sun Nov 25 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Disabled OpenJPEG support until we have a patch for OpenJPEG 2.0 final
* Sun Oct 14 2012 schwab@linux-m68k.org
- gdal-postgisraster-array-overflow.patch
  PostGISRaster: fix array overflow
* Fri Oct 12 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Update to new release 1.9.2:
    Fix infinite GDALOpen recursion with some VRTs (#4835)
    Avoid destroying existing overviews (.aux/.rrd) (#4831)
    Support recognising NaN better in !CPLStrtod() (#4799)
    Fix windows declaration for !CPLGetErrorHandlerUserData() (#4755)
    Fix compilation with Gentoo modified zlib 1.2.6 (#4723)
    Look for libgeotiff headers in /usr/include/libgeotiff too (#4706)
    Improve warning handling in !CPLClearRecodeStubWarningFlags() (#4650)
    Fix Solaris compilation bug (#4705)
    !MorphFromESRI(): compare SPHEROID/PRIMEM parms, not names (#4673)
* Thu Sep 27 2012 behrisch@users.sourceforge.net
- fixing sles dependencies
* Wed Sep 26 2012 behrisch@users.sourceforge.net
- fixing sles 10 build by not regenerating swig files
* Wed Sep 19 2012 behrisch@users.sourceforge.net
- fixed ScientificLinux dependencies
* Fri Sep 14 2012 behrisch@users.sourceforge.net
- Fixed CentOS 6 and ScientificLinux 6 build
- Fixed SLE build
* Fri Jun 29 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- added new parameters to avoid issue:
    https://bugs.archlinux.org/task/30471
    http://www.mail-archive.com/ubuntu@lists.osgeo.org/msg00330.html
* Fri Jun 15 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Fixed Factory build
- Added poppler patch from branch 1.9
- Added libgeotiff include path patch (now upstream too)
* Fri Jun  1 2012 kukuk@suse.de
- remove obsolete doxygen patch
* Thu May 31 2012 kukuk@suse.de
- Fix libXerces-c dependency for SLES
* Wed May 23 2012 tzotsos@opensuse.org
- Update to new release 1.9.1
  * fix crash with VSICachedFile::Read() for large reads (#4646)
  * Unix VSI*L: correctly set current offset after a failed read (#4583)
  * Improve OpenJDK finding logic in configure. (#4643)
  * Fix iconv configure problem on FreeBSD (#4525)
  * Fix MinGW build when pthread is also available (#4430)
  * makegdalXX.vcproj : update 71,80 and 90 version. Drop 10 version --> open the 90 version and VS2010 should convert it (#4415)
  * reverseWindingOrder(): don't force coordinate dimension to 3 (#4621)
  * Fix incorrect rounding in OGRFormatDouble (#4614)
  * Fix segfault when running 'ogr2ogr target src -select AFIELD -where FID=xxx' when the source layer has more than 5 fields (#4500)
- gdal-sqlite.patch moved upstream http://trac.osgeo.org/gdal/ticket/4515
* Sat May 12 2012 behrisch@users.sourceforge.net
- fixed scientific linux build
- moved to external libgeotiff which works better with QLandkarteGT
* Wed Apr  4 2012 behrisch@users.sf.net
- fixed RHEL6 (and derivatives) build
* Wed Feb 15 2012 dassau@gbd-consult.de
- added gdal-sqlite.patch to fix http://trac.osgeo.org/gdal/ticket/4515
* Tue Jan 10 2012 dassau@gbd-consult.de
- Update to new release 1.9.0
  * New GDAL drivers: ACE2, CTG, E00GRID, ECRGTOC, GRASSASCIIGrid,
    GTA, NGSGEOID, SNODAS, WebP, ZMap
  * New OGR drivers:  ARCGEN, CouchDB, DWG, EDIGEO, ESRI FileGDB, Geomedia,
    Google Fusion Tables, IDRISI, MDB, SEGUKOOA, SEGY, SVG, XLS
  * Significantly improved drivers: NetCDF
  * Encoding support for shapefile/dbf (#882)
  * RFC 35: Delete, reorder and alter field definitions of OGR layers
  * RFC 37: Add mechanism to provide user data to CPLErrorHandler (#4295)
  * gdalsrsinfo: new supported utility to report SRS in various form
    (supercedes testepsg)
* Thu Jul 21 2011 dassau@gbd-consult.de
- Update to new release 1.8.1
* Wed Apr 27 2011 dassau@gbd-consult.de
- Added curl as dependency to support (wms/wcs/...)
* Sun Apr 24 2011 toddrme2178@gmail.com
- Switched to valid groups (fix for RPMLINT warning)
* Thu Apr 14 2011 behrisch@users.sourceforge.net
- fix CentOS and SLE10 build
* Sat Apr  9 2011 hpj@urpla.net
- fix python dependencies and build, clean up spec
* Mon Jan 24 2011 dassau@gbd-consult.de
- update to new version
  Sat Nov 13 00:00:00 UTC 2010 - Otto Dassau 1.7.3
- update to new version with many small fixes and changes
  Thu Jun 24 00:00:00 UTC 2010 - Otto Dassau 1.7.1
- added soname patch for building without libtool
  Wed Apr 14 00:00:00 UTC 2010 - Otto Dassau 1.7.1
- added perl and python packages with help from fedora spec by Balint Cristian
  Thu Feb 11 00:00:00 UTC 2010 - Otto Dassau 1.7.1
- update to new version
  Mon Nov 30 00:00:00 UTC 2009 - Otto Dassau 1.6.3
- update to new version
  Tue Nov 24 00:00:00 UTC 2009 - Otto Dassau 1.6.2
- update to new version
  Mon May 18 00:00:00 UTC 2009 - Otto Dassau 1.6.1
- update to new version
  Wed Feb 18 00:00:00 UTC 2009 - Otto Dassau 1.6.0
- update to new version
- adapted hdf4 patch
- removed ogpython and enabled current python bindings
  Thu Dec  4 00:00:00 UTC 2008 - Otto Dassau 1.5.3
- new patch to prevent getting upside-down images with NetCDF (ticket 2654)
  Tue Oct 21 00:00:00 UTC 2008 - Otto Dassau 1.5.3
- update to new version
  Thu Jun 12 00:00:00 UTC 2008 - Otto Dassau 1.5.2
- update to new bugfix version and added hdf4 support
  Sun Mar 23 00:00:00 UTC 2008 - Otto Dassau 1.5.1
- update to new version
  Mon Dec 31 00:00:00 UTC 2007 - Otto Dassau 1.5.0
- added with-ogpython
- BuildRequires: +unixODBC-devel, +libgeos-devel
- added more tools
  Thu Dec 20 00:00:00 UTC 2007 - Otto Dassau 1.4.4
- update to 1.4.4 and added mysql support
  Mon Aug 13 00:00:00 UTC 2007 - Dirk Stoecker 1.4.2
- adapted for openSUSE BuildService
  Mon Jul 16 00:00:00 UTC 2007 - Otto Dassau 1.4.2
- first built
  Mon Jun 11 00:00:00 UTC 2007 - Otto Dassau 1.4.1
- first built
  Tue Dec 19 00:00:00 UTC 2006 - Otto Dassau 1.3.2
- built on SuSE 10.2
  Mon Jun 19 00:00:00 UTC 2006 - Markus Neteler 1.3.2
- added DB support; gdal_rasterize
  Wed Jan 25 00:00:00 UTC 2006 - Otto Dassau 1.3.1
- adapted to SuSE 10.0
